[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,101 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDA Experimental in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#ifndef __COMMON_HOST_DEVICE_H__
|
||||
#define __COMMON_HOST_DEVICE_H__
|
||||
|
||||
#include "utility.cuh"
|
||||
|
||||
template <typename Dims, typename Lambda>
|
||||
void __global__ lambda_launcher(const Dims dims, const Lambda lambda)
|
||||
{
|
||||
lambda(dims);
|
||||
}
|
||||
|
||||
template <typename Comparator, unsigned int FilterArch>
|
||||
bool arch_filter(const cudaDeviceProp& props)
|
||||
{
|
||||
int act_arch = props.major * 10 + props.minor;
|
||||
if (Comparator()(act_arch, FilterArch))
|
||||
{
|
||||
return true;
|
||||
}
|
||||
return false;
|
||||
}
|
||||
|
||||
static bool skip_host_exec(bool (* /* filter */)(const cudaDeviceProp&))
|
||||
{
|
||||
return false;
|
||||
}
|
||||
|
||||
static bool skip_device_exec(bool (*filter)(const cudaDeviceProp&))
|
||||
{
|
||||
cudaDeviceProp props;
|
||||
REQUIRE_CUDART(cudaGetDeviceProperties(&props, 0));
|
||||
return filter(props);
|
||||
}
|
||||
|
||||
template <typename Dims, typename Lambda, typename... Filters>
|
||||
void test_host_dev(const Dims& dims, const Lambda& lambda, const Filters&... filters)
|
||||
{
|
||||
SECTION("Host execution")
|
||||
{
|
||||
if ((... && !skip_host_exec(filters)))
|
||||
{
|
||||
// host testing
|
||||
lambda(dims);
|
||||
}
|
||||
}
|
||||
|
||||
SECTION("Device execution")
|
||||
{
|
||||
// Asymmetrical but cleaner
|
||||
if ((... || skip_device_exec(filters)))
|
||||
{
|
||||
return;
|
||||
}
|
||||
|
||||
cudaLaunchConfig_t config = {};
|
||||
config.gridDim = {0};
|
||||
cudaLaunchAttribute attrs[1];
|
||||
config.attrs = &attrs[0];
|
||||
|
||||
config.blockDim = dims.extents(cuda::gpu_thread, cuda::block);
|
||||
config.gridDim = dims.extents(cuda::block, cuda::grid);
|
||||
|
||||
if constexpr (Dims::has_level(cluster))
|
||||
{
|
||||
dim3 cluster_dims = dims.extents(cuda::block, cuda::cluster);
|
||||
config.attrs[config.numAttrs].id = cudaLaunchAttributeClusterDimension;
|
||||
config.attrs[config.numAttrs].val.clusterDim = {cluster_dims.x, cluster_dims.y, cluster_dims.z};
|
||||
config.numAttrs = 1;
|
||||
}
|
||||
else
|
||||
{
|
||||
config.numAttrs = 0;
|
||||
}
|
||||
|
||||
// device testing
|
||||
REQUIRE_CUDART(cudaLaunchKernelEx(&config, lambda_launcher<Dims, Lambda>, dims, lambda));
|
||||
REQUIRE_CUDART(cudaDeviceSynchronize());
|
||||
}
|
||||
}
|
||||
|
||||
template <typename Fn, typename Tuple>
|
||||
void apply_each(const Fn& fn, const Tuple& tuple)
|
||||
{
|
||||
cuda::std::apply(
|
||||
[&](const auto&... elems) {
|
||||
(fn(elems), ...);
|
||||
},
|
||||
tuple);
|
||||
}
|
||||
|
||||
#endif // __COMMON_HOST_DEVICE_H__
|
||||
Reference in New Issue
Block a user